aboutsummaryrefslogtreecommitdiffstats
path: root/gowin/arch.h
diff options
context:
space:
mode:
Diffstat (limited to 'gowin/arch.h')
-rw-r--r--gowin/arch.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/gowin/arch.h b/gowin/arch.h
index a5c339cc..0dd5a62b 100644
--- a/gowin/arch.h
+++ b/gowin/arch.h
@@ -479,6 +479,7 @@ struct Arch : BaseArch<ArchRanges>
void post_route(Context *ctx);
void auto_longwires();
void add_plla_ports(BelsPOD const *bel, IdString belname, int row, int col);
+ void add_pllvr_ports(DatabasePOD const *db, BelsPOD const *bel, IdString belname, int row, int col);
void fix_pll_nets(Context *ctx);
bool is_GCLKT_iob(const CellInfo *cell);
@@ -507,6 +508,9 @@ struct Arch : BaseArch<ArchRanges>
// Permissible combinations of modes in a single slice
std::map<const IdString, IdString> dff_comp_mode;
+
+ // max global clock wires
+ int max_clock;
};
// Bels Z range
@@ -521,7 +525,8 @@ enum
osc_z = 280, // Z for the oscillator bels
bufs_0_z = 281, // Z for long wire buffer bel
pll_z = 289, // PLL
- free_z = 290 // Must be the last, one can use z starting from this value, adjust accordingly.
+ pllvr_z = 290, // PLLVR
+ free_z = 291 // Must be the last, one can use z starting from this value, adjust accordingly.
};
}